export declare function getBufferClass(): BufferConstructor;
export declare enum Endian {
    LE = 0,
    BE = 1
}
export declare function createReader(endianness: Endian, buffer: Buffer): IReader;
export declare function createWriter(endianness: Endian, size?: number): IWriter;
export interface IReader {
    readOffset: number;
    length: number;
    readBuffer(bytes: number): Buffer;
    readUint8Array(bytes: number): Uint8Array;
    readByte(): number;
    readUByte(): number;
    readBool(): boolean;
    readUShortString(): string;
    readShortString(): string;
    readBytesAsString(bytesToRead: number): string;
    readVarint(): number;
    readShort(): number;
    readUShort(): number;
    readInt(): number;
    readUInt(): number;
    readLong(): bigint;
    readULong(): bigint;
    readFloat(): number;
    readDouble(): number;
    readUString(): string;
    readString(): string;
    readShortsAsString(shortsToRead: number): string;
    readUString16(): string;
    readString16(): string;
    readArbInt(length: number): number;
    readArbUInt(length: number): number;
}
export interface IWriter {
    writeOffset: number;
    length: number;
    toBuffer(): Buffer;
    toString(): string;
    writeBuffer(buffer: Buffer): IWriter;
    writeUint8Array(array: Uint8Array): IWriter;
    writeByte(value: number): IWriter;
    writeUByte(value: number): IWriter;
    writeBool(value: boolean | number): IWriter;
    writeStringAsBytes(text: string): IWriter;
    writeVarint(value: number): IWriter;
    writeShort(value: number): IWriter;
    writeUShort(value: number): IWriter;
    writeInt(value: number): IWriter;
    writeUInt(value: number): IWriter;
    writeLong(value: number | bigint): IWriter;
    writeULong(value: number | bigint): IWriter;
    writeFloat(value: number): IWriter;
    writeDouble(value: number): IWriter;
    writeUShortString(text: string): IWriter;
    writeShortString(text: string): IWriter;
    writeUString(text: string): IWriter;
    writeString(text: string): IWriter;
    writeUString16(text: string): IWriter;
    writeString16(text: string): IWriter;
    writeStringAsShorts(text: string): IWriter;
    writeJavaUTF(text: string): IWriter;
}
